<?php

/*
  Plugin Name: Tickera Custom Orders Page Modified
  Plugin URI: http://tickera.com/
  Description: Modify ordfers page without it being overwritten when Tickera updates. Use 'tc_order_details_modified' shortcode
  Author: Tickera.com
  Author URI: http://tickera.com/
  Version: 1.0
  Copyright 2017 Tickera (http://tickera.com/)
 */

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

if (!class_exists('TC_Order_Details_Modified')) {

    class TC_Order_Details_Modified {

        var $version = '1.2.4.6';
        var $title = 'Order Details Modified';
        var $name = 'tc-order-details-changed';
        var $dir_name = 'tc-order-details-changed';
        var $location = 'plugins';
        var $plugin_dir = '';
        var $plugin_url = '';

        function __construct() {

            $this->init_vars();
            
            add_action('plugins_loaded', array(&$this, 'localization'), 9);
 
            add_shortcode('tc_order_details_modified', array(&$this, 'tc_order_details_page_modified'));

            if (isset($_GET['page']) && $_GET['page'] == 'tc_settings' && isset($_GET['tab']) && $_GET['tab'] == 'tickera_export_csv_mixed_data') {
                add_action('admin_enqueue_scripts', array(&$this, 'enqueue_scripts'));
            }
        }

        
    function tc_order_details_page_modified($atts) {
        global $tc, $wp;
        ob_start();
        include_once( $dir_name . 'includes/templates/page-order-modified.php' );
        $content = wpautop(ob_get_clean(), true);
        return $content;
    }
        

      
        //Plugin localization function
        function localization() {
// Load up the localization file if we're using WordPress in a different language
// Place it in this plugin's "languages" folder and name it "tccsv-[value in wp-config].mo"
            if ($this->location == 'mu-plugins') {
                load_muplugin_textdomain('tccsv', 'languages/');
            } else if ($this->location == 'subfolder-plugins') {
//load_plugin_textdomain( 'tccsv', false, $this->plugin_dir . '/languages/' );
                load_plugin_textdomain('tccsv', false, dirname(plugin_basename(__FILE__)) . '/languages/');
            } else if ($this->location == 'plugins') {
                load_plugin_textdomain('tccsv', false, 'languages/');
            } else {
                
            }

            $temp_locales = explode('_', get_locale());
            $this->language = ($temp_locales[0]) ? $temp_locales[0] : 'en';
        }
        
        function init_vars() {
            //setup proper directories
            if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename(__FILE__))) {
                $this->location = 'subfolder-plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url = plugins_url('/', __FILE__);
            } else if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/';
                $this->plugin_url = plugins_url('/', __FILE__);
            } else if (is_multisite() && defined('WPMU_PLUGIN_URL') && defined('WPMU_PLUGIN_DIR') && file_exists(WPMU_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'mu-plugins';
                $this->plugin_dir = WPMU_PLUGIN_DIR;
                $this->plugin_url = WPMU_PLUGIN_URL;
            } else {
                wp_die(sprintf(__('There was an issue determining where %s is installed. Please reinstall it.', 'tccsv'), $this->title));
            }
        }

        function enqueue_scripts() {


        }

    }

}


    function tc_get_order_details_front_modified($order_id = '', $order_key = '', $return = false) {
        global $tc;

        if ($return) {
            ob_start();
        }

        $tc_general_settings = get_option('tc_general_setting', false);

        $order = new TC_Order($order_id);
        $init_order_id = $order_id;

        if ($order->details->tc_order_date == $order_key) {//key must match order creation date for security reasons
            if ($order->details->post_status == 'order_received') {
                $order_status = __('Pending Payment', 'tc');
            } else if ($order->details->post_status == 'order_fraud') {
                $order_status = __('Under Review', 'tc');
            } else if ($order->details->post_status == 'order_paid') {
                $order_status = __('Payment Completed', 'tc');
            } else if ($order->details->post_status == 'trash') {
                $order_status = __('Order Deleted', 'tc');
            } else if ($order->details->post_status == 'order_cancelled') {
                $order_status = __('Order Cancelled', 'tc');
            } else {
                $order_status = $order->details->post_status;
            }

            $fees_total = apply_filters('tc_cart_currency_and_format', $order->details->tc_payment_info['fees_total']);
            $tax_total = apply_filters('tc_cart_currency_and_format', $order->details->tc_payment_info['tax_total']);
            $subtotal = apply_filters('tc_cart_currency_and_format', $order->details->tc_payment_info['subtotal']);
            $total = apply_filters('tc_cart_currency_and_format', $order->details->tc_payment_info['total']);
            $transaction_id = isset($order->details->tc_payment_info['transaction_id']) ? $order->details->tc_payment_info['transaction_id'] : '';
            $order_id = strtoupper($order->details->post_name);
            $order_date = $payment_date = apply_filters('tc_order_date', tc_format_date($order->details->tc_order_date, true)); //date_i18n( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), $order->details->tc_order_date, false )
            ?>

            <label><span class="order_details_title"><?php _e('Order: ', 'tc'); ?></span> <?php echo $order_id; ?></label>
            <label><span class="order_details_title"><?php _e('Order date: ', 'tc'); ?></span> <?php echo $order_date; ?></label>
            <label><span class="order_details_title"><?php _e('Order status: ', 'tc'); ?></span> <?php echo $order_status; ?></label>
            <?php if (isset($transaction_id) && $transaction_id !== '') { ?>
                <label><span class="order_details_title"><?php _e('Transaction ID: ', 'tc'); ?></span> <?php echo $transaction_id; ?></label>
            <?php } ?>
            <label><span class="order_details_title"><?php _e('Subtotal: ', 'tc'); ?></span> <?php echo $subtotal; ?></label>
            <?php if (!isset($tc_general_settings['show_fees']) || isset($tc_general_settings['show_fees']) && $tc_general_settings['show_fees'] == 'yes') { ?>
                <label><span class="order_details_title"><?php echo isset($tc_general_settings['fees_label']) ? $tc_general_settings['fees_label'] : __('Fees', 'tc'); ?></span> <?php echo $fees_total; ?></label>
            <?php } ?>
            <?php if (!isset($tc_general_settings['show_tax_rate']) || isset($tc_general_settings['show_tax_rate']) && $tc_general_settings['show_tax_rate'] == 'yes') { ?>
                <label><span class="order_details_title"><?php echo isset($tc_general_settings['tax_label']) ? $tc_general_settings['tax_label'] : __('Tax', 'tc'); ?></span> <?php echo $tax_total; ?></label>
            <?php } ?>
            <hr />
            <label><span class="order_details_title"><?php _e('Total: ', 'tc'); ?></span> <?php echo $total; ?></label>

            <?php
            tc_order_details_table_front($init_order_id, $return);
        } else {
            _e("You don't have required permissions to access this page.", 'tc');
        }

        do_action('tc_after_order_details', $order_id);

        if ($return) {
            $content = wpautop(ob_get_clean(), true);
            return $content;
        }
    }

$tc_order_details_modified = new TC_Order_Details_Modified();

?>